#ifndef NT2_INCLUDE_FUNCTIONS_IS_NEGATIVE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_NEGATIVE_HPP_INCLUDED

#include <nt2/predicates/include/functions/is_negative.hpp>

#endif
